'use strict';

const fetchres = require('fetchres');
const logger = require('ft-next-logger').logger;

module.exports = (opts) => {
	const identifierValues = opts.identifierValues;
	const authority = opts.authority || 'http://api.ft.com/system/FT-TME';

	if(opts.identifierValues.length === 0 || !Array.isArray(opts.identifierValues)) {
		return Promise.resolve([]);
	}

	return fetch('https://next-es-interface.ft.com/things', {
		method: 'POST',
		body: JSON.stringify({
			identifierValues,
			authority
		}),
		timeout: 3000,
		headers: {
			'Content-Type': 'application/json'
		}
	})
	.then(fetchres.json)
	.then((results) => {
		const items = results
					.filter(r => r.status === 200)
					.map(r => r.body.term);
		return {
			total: items.length,
			items
		};
	})
	.catch((err) => {
		logger.warn('Failed getting ElasticSearch things', {
			identifierValues,
			error: err
		});
	});
};
