/*global describe, context, it, beforeEach, afterEach*/
'use strict';

GLOBAL.fetch = require('node-fetch');

const nock = require('nock');
const expect = require('chai').expect;
const subject = require('../main').relatedTags;

describe('related tags', () => {

	context('success', () => {

		let result;
		let request;

		beforeEach(() => {
			request = nock('https://next-elastic.ft.com')
				.post('/v3_api_v2/item/_search', /"metadata\.idV1":"success"/)
				.once()
				.reply(200, require('./fixtures/related-tags-elastic.json'));

			return subject({
				taxonomies: [ 'topics', 'sections', 'people', 'organisations' ],
				id: 'success',
				range: 60
			})
				.then(data => result = data);
		});

		afterEach(() => {
			result = null;
			request.isDone();
		});

		it('returns an one-dimensional array of objects', () => {
			expect(result).to.be.an('array');
			expect(result.length).to.equal(12);

			result.forEach(tag => {
				expect(tag).to.be.an('object');
				expect(tag).to.include.keys('prefLabel', 'taxonomy', 'idV1');
			});
		});

		it('returns each tag with mapped name and taxonomy', () => {
			expect(result[0].prefLabel).to.eq('Markets');
			expect(result[0].taxonomy).to.eq('sections');
		});

	});

	context('failure', () => {

		let result;
		let request;

		beforeEach(() => {
			request = nock('https://next-elastic.ft.com')
				.post('/v3_api_v2/item/_search', /"metadata\.idV1":"failure"/)
				.once()
				.reply(500, { omg: 'wtf' });

			return subject({
				taxonomies: [ 'topics', 'sections', 'people', 'organisations' ],
				id: 'failure',
				range: 60
			})
				.then(data => result = data);
		});

		afterEach(() => {
			result = null;
			request.isDone();
		});

		it('still returns an array', () => {
			expect(result).to.be.an('array');
			expect(result.length).to.equal(0);
		});

	});

});
